import { ContentView, ChildCursor } from "./contentview";
import { BlockView } from "./blockview";
import { CompositionView } from "./inlineview";
import { Viewport, ViewportState } from "./viewport";
import { DOMObserver } from "./domobserver";
import { HeightMap, HeightOracle, BlockInfo } from "./heightmap";
import { DecorationSet } from "./decoration";
import { Rect } from "./dom";
import { EditorView } from "./editorview";
import { EditorState, ChangedRange, Transaction } from "../../state/src";
import { Slot } from "../../extension/src/extension";
declare type A<T> = ReadonlyArray<T>;
declare const enum Composing {
    No = 0,
    Starting = 1,
    Yes = 2,
    Ending = 3
}
export declare class DocView extends ContentView {
    private view;
    children: BlockView[];
    viewports: Viewport[];
    decorations: A<DecorationSet>;
    gapDeco: DecorationSet;
    selectionDirty: any;
    observer: DOMObserver;
    forceSelectionUpdate: boolean;
    viewportState: ViewportState;
    heightMap: HeightMap;
    heightOracle: HeightOracle;
    layoutCheckScheduled: number;
    scrollIntoView: number;
    composing: Composing;
    composition: CompositionView | null;
    composeTimeout: any;
    paddingTop: number;
    paddingBottom: number;
    dom: HTMLElement;
    readonly length: number;
    readonly state: EditorState;
    readonly viewport: Viewport;
    readonly root: DocumentOrShadowRoot;
    constructor(view: EditorView, onDOMChange: (from: number, to: number, typeOver: boolean) => boolean);
    init(state: EditorState): void;
    update(transactions: A<Transaction>, state: EditorState, metadata: Slot[], scrollIntoView?: number): void;
    private updateInner;
    private updateChildren;
    private replaceRange;
    updateSelection(takeFocus?: boolean): void;
    lineAt(pos: number, editorTop?: number): BlockInfo;
    lineAtHeight(height: number, editorTop?: number): BlockInfo;
    blockAtHeight(height: number, editorTop?: number): BlockInfo;
    forEachLine(from: number, to: number, f: (line: BlockInfo) => void, editorTop?: number): void;
    computeUpdate(trs: A<Transaction> | null, // Null means we're initializing
    state: EditorState, metadata: Slot[], contentChanges: A<ChangedRange>, viewportBias: number, scrollIntoView: number): A<ChangedRange>;
    focus(): void;
    cancelLayoutCheck(): void;
    forceLayout(): void;
    checkLayout(forceFull?: boolean): void;
    scrollPosIntoView(pos: number): void;
    nearest(dom: Node): ContentView | null;
    posFromDOM(node: Node, offset: number): number;
    domFromPos(pos: number): {
        node: Node;
        offset: number;
    } | null;
    coordsAt(pos: number): Rect | null;
    measureVisibleLineHeights(): any[];
    measureVerticalPadding(): void;
    measureTextSize(): {
        lineHeight: number;
        charWidth: number;
    };
    destroy(): void;
    clearSelectionDirty(): void;
    setSelectionDirty(): void;
    startComposition(): void;
    endComposition(): void;
    commitComposition(changes: A<ChangedRange>): A<ChangedRange>;
    enterComposition(): void;
    clearComposition(changes: A<ChangedRange>): A<ChangedRange>;
    exitComposition(): void;
    childCursor(pos?: number, i?: number): ChildCursor;
    computeGapDeco(viewports: A<Viewport>, docLength: number): DecorationSet;
}
export {};
